@@ -422,28 +422,43 @@ class DltkAiClient:
         else:
             raise Exception('Error while checking the status. Got ' + str(response.status_code))
 
-    def text_to_speech(self, text, gender):
+
+    def visual_search(self, image_path_1, image_path_2):
+        """
+        :param str image_path_1: The path of the image file
+        :param str image_path_1: The path of the image file
+        :return
+            obj : A json obj containing matched status and value info
+        """
+        body = {'image_1': (image_path_1, open(image_path_1, 'rb'), 'multipart/form-data'), 'image_2': (image_path_2, open(image_path_2, 'rb'), 'multipart/form/data')}
+        url = self.base_url + '/visual_search_ai/'
+        headers = {'ApiKey': self.api_key}
+        response = requests.post(url=url, files=body, headers=headers).json()
+        return response 
+           
+
+    def text_to_speech(self, text):
         """
         :param str text: the text on which tts is to be applied.
         :param str gender: text to speech supports 'MALE' , 'FEMALE' or 'NEUTRAL'
         :return:
             obj: A audio content obj which can be written into a audio file.
         """
-        body = {'text': text, 'gender': gender}
+        body = {'body': text}
         body = json.dumps(body)
-        url = self.base_url + '/core/text-to-speech/'
+        url = self.base_url + '/text_to_voice_ai/'
         headers = {'ApiKey': self.api_key, 'Content-Type': 'application/json'}
         response = requests.post(url=url, data=body, headers=headers)
         return response.content
 
-    def speech_to_text(self, audio_path):
+    def speech_to_text(self, audio_path, language):
         """
         :param str audio_path: the path of the audio file.
         :return:
             obj: A json obj containing transcript of the audio file.
         """
         body = {'audio': (audio_path, open(audio_path, 'rb'), 'multipart/form-data')}
-        url = self.base_url + '/core/speech-to-text/'
+        url = self.base_url + '/voice_ai/?language={0}'.format(language)
         headers = {'ApiKey': self.api_key}
         response = requests.post(url=url, files=body, headers=headers).json()
         return response
